@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('pagehelp.views',
     url(r'^hide/$', 'set_default', {'show': False}, name='default_hide'),
